MiniProgramAuthBackendPaths class

Annotations

Constructors

MiniProgramAuthBackendPaths({String emailSignIn = 'auth/email/sign-in', String emailSignUp = 'auth/email/sign-up', String refresh = 'auth/refresh', String signOut = 'auth/sign-out', String session = 'auth/session'})
const

Properties

emailSignIn String
final
emailSignUp String
final
hashCode int
The hash code for this object.
no setterinherited
refresh String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session String
final
signOut String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited