MiniProgramAuthController class

Inheritance

Constructors

MiniProgramAuthController({required MiniProgramAuthStore store, MiniProgramAuthBackendPaths paths = const MiniProgramAuthBackendPaths(), MiniProgramAuthClock? clock})
MiniProgramAuthController.inMemory({MiniProgramAuthBackendPaths paths = const MiniProgramAuthBackendPaths(), MiniProgramAuthClock? clock})
factory
MiniProgramAuthController.secure({MiniProgramAuthBackendPaths paths = const MiniProgramAuthBackendPaths(), FlutterSecureStorage? storage, MiniProgramAuthClock? clock})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
paths MiniProgramAuthBackendPaths
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
authorizeRequest({required MiniProgramBackendRequest request, required MiniProgramBackendConnector? connector}) Future<MiniProgramBackendRequest>
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
refresh({required String miniProgramId, required MiniProgramBackendConnector connector}) Future<MiniProgramAuthResult>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
restore({required String miniProgramId, required MiniProgramBackendConnector? connector}) Future<MiniProgramAuthResult>
session(String miniProgramId) MiniProgramAuthSession?
signInEmail({required String miniProgramId, required MiniProgramBackendConnector connector, required String email, required String password}) Future<MiniProgramAuthResult>
signOut({required String miniProgramId, required MiniProgramBackendConnector? connector}) Future<MiniProgramAuthResult>
signUpEmail({required String miniProgramId, required MiniProgramBackendConnector connector, required String email, required String password}) Future<MiniProgramAuthResult>
snapshot(String miniProgramId) MiniProgramAuthSnapshot
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited