MiniProgramAuthSession class

Annotations

Constructors

MiniProgramAuthSession({required String miniProgramId, required MiniProgramAuthUser user, required String idToken, required String refreshToken, required DateTime expiresAtUtc})
const
MiniProgramAuthSession.fromJson(Map<String, dynamic> json)
factory

Properties

expiresAtUtc DateTime
final
hashCode int
The hash code for this object.
no setterinherited
idToken String
final
miniProgramId String
final
refreshToken String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user MiniProgramAuthUser
final

Methods

isExpired({DateTime? nowUtc, Duration skew = const Duration(seconds: 30)}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBindingData() Map<String, dynamic>
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBackendData({required String miniProgramId, required Map<String, dynamic> data, required DateTime nowUtc}) MiniProgramAuthSession