MiniProgramAuthSnapshot class

Annotations

Properties

authenticated bool
no setter
errorCode String?
final
expiresAtUtc DateTime?
final
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
loading bool
no setter
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signedOut bool
no setter
status MiniProgramAuthStatus
final
user MiniProgramAuthUser?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBindingData() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited