CachedManifestEntry class

Annotations

Constructors

CachedManifestEntry({required String miniProgramId, required MiniProgramManifest manifest, required DateTime cachedAt})
const
CachedManifestEntry.fromJson(Map<String, dynamic> json)
factory

Properties

cachedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
manifest → MiniProgramManifest
final
miniProgramId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited