CachedScreenEntry class
- Annotations
Constructors
-
CachedScreenEntry({required String miniProgramId, required String version, required String screenId, required Map<
String, dynamic> screenJson, required DateTime cachedAt}) -
const
-
CachedScreenEntry.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cachedAt → DateTime
-
final
- cacheKey → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- miniProgramId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenId → String
-
final
-
screenJson
→ Map<
String, dynamic> -
final
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited