InMemoryScreenCache class

Implemented types

Constructors

InMemoryScreenCache()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({required String miniProgramId, required String version, required String screenId}) Future<CachedScreenEntry?>
override
remove({required String miniProgramId, required String version, required String screenId}) Future<void>
override
toString() String
A string representation of this object.
inherited
write(CachedScreenEntry entry) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared InMemoryScreenCache
final