MiniProgramCacheBundle class

Cache bundle used by hosts to pass both manifest and screen cache stores.

Annotations

Constructors

MiniProgramCacheBundle({required ManifestCache manifestCache, required ScreenCache screenCache, required AssetCache assetCache, required MiniProgramCacheManager runtimeCache})
const
MiniProgramCacheBundle.fileBacked({required Directory rootDirectory})
factory
MiniProgramCacheBundle.inMemory()
factory
MiniProgramCacheBundle.webPersistent({String runtimeCacheKeyPrefix = 'mini_program_runtime_cache'})
factory

Properties

assetCache AssetCache
final
hashCode int
The hash code for this object.
no setterinherited
manifestCache ManifestCache
final
runtimeCache MiniProgramCacheManager
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenCache ScreenCache
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited