MiniProgramAppCache class

Properties

appId String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear({MiniProgramCacheBucket? bucket}) Future<void>
get<T>(String key, {MiniProgramCacheBucket bucket = MiniProgramCacheBucket.data}) Future<T?>
has(String key, {MiniProgramCacheBucket bucket = MiniProgramCacheBucket.data}) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key, {MiniProgramCacheBucket bucket = MiniProgramCacheBucket.data}) Future<void>
set(String key, Object? value, {MiniProgramCacheBucket bucket = MiniProgramCacheBucket.data, Duration? ttl, MiniProgramCachePriority priority = MiniProgramCachePriority.normal}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited