MiniProgramCacheMetadata class

Annotations

Constructors

MiniProgramCacheMetadata({required String appId, required DateTime firstOpenedAt, required DateTime lastOpenedAt, required DateTime lastAccessedAt, required int totalBytes, required int dataBytes, required int imageBytes, int audioBytes = 0, required int videoBytes, required int sessionBytes, required int stateBytes})
const

Properties

appId String
final
audioBytes int
final
dataBytes int
final
firstOpenedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
imageBytes int
final
lastAccessedAt DateTime
final
lastOpenedAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionBytes int
final
stateBytes int
final
totalBytes int
final
videoBytes int
final

Methods

copyWith({DateTime? firstOpenedAt, DateTime? lastOpenedAt, DateTime? lastAccessedAt, int? totalBytes, int? dataBytes, int? imageBytes, int? audioBytes, int? videoBytes, int? sessionBytes, int? stateBytes}) MiniProgramCacheMetadata
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited