MiniProgramCacheStore class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearApp(String appId) Future<void>
clearBucket(String appId, MiniProgramCacheBucket bucket) Future<void>
entries(String appId) Future<List<MiniProgramCacheEntry>>
get(String namespacedKey) Future<MiniProgramCacheEntry?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String namespacedKey) Future<void>
set(MiniProgramCacheEntry entry) Future<void>
toString() String
A string representation of this object.
inherited
totalBytes(String appId) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited