MiniProgramCacheUsage class

Annotations

Constructors

MiniProgramCacheUsage({required String appId, required bool enabled, required int usedBytes, required int maxBytes, required int remainingBytes, required int entryCount, required Map<MiniProgramCacheBucket, MiniProgramCacheBucketUsage> buckets})
const

Properties

appId String
final
buckets Map<MiniProgramCacheBucket, MiniProgramCacheBucketUsage>
final
enabled bool
final
entryCount int
final
hashCode int
The hash code for this object.
no setterinherited
maxBytes int
final
remainingBytes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usedBytes int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMiniProgramJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited