- Implemented types
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appIds(
) → Future< List< String> > -
clearApp(
String appId) → Future< void> -
inherited
-
clearBucket(
String appId, MiniProgramCacheBucket bucket) → Future< void> -
inherited
-
entries(
String appId) → Future< List< MiniProgramCacheEntry> > -
inherited
-
get(
String namespacedKey) → Future< MiniProgramCacheEntry?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String namespacedKey) → Future< void> -
inherited
-
set(
MiniProgramCacheEntry entry) → Future< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
totalBytes(
String appId) → Future< int> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited