MiniProgramCameraCaptureRequest class

Trusted request passed to a host camera implementation.

Annotations

Constructors

MiniProgramCameraCaptureRequest({required String captureId, required String miniProgramId, required int quality, int? maxWidth, int? maxHeight})
const

Properties

captureId String
final
hashCode int
The hash code for this object.
no setterinherited
maxHeight int?
final
maxWidth int?
final
miniProgramId String
final
quality int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited