CapabilityRegistry class
Immutable registry of capabilities supported by the current host app.
Constructors
-
CapabilityRegistry(Iterable<
Object?> supportedCapabilities)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedCapabilities
→ Set<
CapabilityId> -
no setter
Methods
-
missingCapabilities(
Iterable< Object?> capabilities) → Set<CapabilityId> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supports(
Object? capability) → bool -
supportsAll(
Iterable< Object?> capabilities) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited