MiniProgramDataResourceLoadResult class

A validated artifact-local JSON resource load result.

Constructors

MiniProgramDataResourceLoadResult({required String id, required String asset, required bool fromCache, required int bytes})
const

Properties

asset String
final
bytes int
final
fromCache bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited