MiniProgramDataResourceManager class
Owns validated JSON resources and bounded search indexes for one runtime.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
load(
{required String appId, required String version, required String resourceId, required String assetPath, required Duration ttl, required bool forceRefresh, required MiniProgramJsonAssetSource? source, required MiniProgramCacheManager cacheManager, required MiniProgramCachePolicy cachePolicy}) → Future< MiniProgramDataResourceLoadResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
search(
{required String appId, required String version, required String resourceId, required String query, required List< String> fields, required String? itemsPath, required int minQueryLength, required int limit, required String targetState}) → Future<Map< String, dynamic> ?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited