MiniProgramDisplayBrightnessManager class
Serializes nested brightness scopes and guarantees restoration.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- provider → MiniProgramDisplayBrightnessProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acquire(
{required String miniProgramId, required Object owner, required double level}) → Future< void> -
dispose(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
Object owner) → Future< void> -
releaseAllFor(
String miniProgramId) → Future< void> -
resume(
) → Future< void> -
suspend(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited