MiniProgramDisplayBrightnessProvider class abstract interface

Applies a temporary brightness override to the active host window.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreBrightness() Future<void>
Restores normal system-controlled window brightness.
setBrightness(double level) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited