MiniProgramFilePolicy class
Host authority for Publisher API file transfers.
- Annotations
Constructors
-
MiniProgramFilePolicy({bool enabled = false, bool allowUpload = false, bool allowDownload = false, Set<
String> allowedMimeTypes = const <String>{'*/*'}, Set<MiniProgramFileDownloadDestination> allowedDestinations = const <MiniProgramFileDownloadDestination>{MiniProgramFileDownloadDestination.downloads, MiniProgramFileDownloadDestination.choose, MiniProgramFileDownloadDestination.temporary}, int maxFilesPerUpload = 10, int maxConcurrentTransfers = 2, int? maxFileBytes, int minimumFreeBytes = 256 * 1024 * 1024}) -
const
Properties
- allowDownload → bool
-
final
-
allowedDestinations
→ Set<
MiniProgramFileDownloadDestination> -
final
-
allowedMimeTypes
→ Set<
String> -
final
- allowUpload → bool
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxConcurrentTransfers → int
-
final
- maxFileBytes → int?
-
Optional host policy cap.
nulldelegates size limits to storage and the provider while retaining streaming and free-space safeguards.final - maxFilesPerUpload → int
-
final
- minimumFreeBytes → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptsMimeType(
String mimeType) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override