MiniProgramFileTransferManager class

Owns transfer identity, concurrency, cancellation, and app isolation.

Properties

hashCode int
The hash code for this object.
no setterinherited
provider MiniProgramFileTransferProvider
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activeCountFor(String miniProgramId) int
cancel(String miniProgramId, String transferId) Future<bool>
cancelAllFor(String miniProgramId) Future<void>
createTransferId(String miniProgramId) String
dispose() Future<void>
download(MiniProgramFileDownloadRequest request, {required MiniProgramFileProgressCallback onProgress}) Future<MiniProgramFileTransferResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(MiniProgramFileUploadRequest request, {required MiniProgramFileProgressCallback onProgress}) Future<MiniProgramFileTransferResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited