MiniProgramFileTransferProvider class abstract interface

Performs native file selection/storage and streaming network transport.

Implementations must stream data, enforce request limits while streaming, remove partial files on failure, and never expose native paths or URIs in returned data.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(String transferId) Future<bool>
download(MiniProgramFileDownloadRequest request, {required MiniProgramFileProgressCallback onProgress}) Future<MiniProgramFileTransferResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(MiniProgramFileUploadRequest request, {required MiniProgramFileProgressCallback onProgress}) Future<MiniProgramFileTransferResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited