MiniProgramFileUploadRequest class
Upload request passed only to a trusted host file provider.
- Annotations
Constructors
-
MiniProgramFileUploadRequest({required String transferId, required String miniProgramId, required MiniProgramResolvedBackendTransfer backend, required List<
String> mimeTypes, required bool multiple, required int maxFiles, required String fieldName, required Map<String, dynamic> metadata, required int? maxFileBytes, required int minimumFreeBytes, required int maxConcurrentTransfers, List<String> mediaRefs = const <String>[]}) -
const
Properties
- backend → MiniProgramResolvedBackendTransfer
-
final
- fieldName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrentTransfers → int
-
final
- maxFileBytes → int?
-
final
- maxFiles → int
-
final
-
mediaRefs
→ List<
String> -
final
-
metadata
→ Map<
String, dynamic> -
final
-
mimeTypes
→ List<
String> -
final
- minimumFreeBytes → int
-
final
- miniProgramId → String
-
final
- multiple → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transferId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited