MiniProgramFlashlightException class

Structured flashlight provider failure.

Implemented types

Constructors

MiniProgramFlashlightException({required String errorCode, required String message, Map<String, Object?> details = const <String, Object?>{}})
const

Properties

details Map<String, Object?>
final
errorCode String
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited