MiniProgramFlashlightManager class
Tracks flashlight ownership and guarantees foreground cleanup.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- provider → MiniProgramFlashlightProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
getStatus(
) → Future< MiniProgramFlashlightStatus> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
releaseFor(
String miniProgramId) → Future< void> -
toggle(
String miniProgramId) → Future< MiniProgramFlashlightStatus> -
toString(
) → String -
A string representation of this object.
inherited
-
turnOff(
String miniProgramId) → Future< MiniProgramFlashlightStatus> -
turnOn(
String miniProgramId) → Future< MiniProgramFlashlightStatus>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited