HostBridge class abstract interface

Host-owned bridge for explicit native or host-specific capabilities.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callSecureApi(CallSecureApiActionPayload payload) Future<HostActionResult>
Calls a host-owned secure API operation through an allowlisted endpoint.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openNativeScreen(OpenNativeScreenActionPayload payload) Future<HostActionResult>
Opens a host-owned native screen.
toString() String
A string representation of this object.
inherited
trackEvent(TrackEventActionPayload payload) Future<HostActionResult>
Sends an analytics event through the host app's analytics stack.

Operators

operator ==(Object other) bool
The equality operator.
inherited