LoadedMiniProgramScreen class

Resolved screen JSON ready for rendering within an already-loaded mini-program.

Constructors

LoadedMiniProgramScreen({required String screenId, required Map<String, dynamic> screenJson, bool usedStaleCache = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenId String
final
screenJson Map<String, dynamic>
final
usedStaleCache bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited