MiniProgramMediaManager class

App-scoped ownership registry and bounded preview cache for opaque media.

Properties

hashCode int
The hash code for this object.
no setterinherited
provider MiniProgramMediaProvider
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
loadPreview({required String miniProgramId, required String mediaRef}) Future<MiniProgramMediaPreviewResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
owns(String miniProgramId, String mediaRef) bool
register({required String miniProgramId, required String mediaRef}) → void
release({required String miniProgramId, required String mediaRef}) Future<bool>
releaseAllFor(String miniProgramId) Future<void>
requireOwned(String miniProgramId, Iterable<String> mediaRefs) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited