MiniProgramMediaProvider class abstract interface

Trusted host access to temporary media without exposing native locations.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadPreview(MiniProgramMediaPreviewRequest request) Future<MiniProgramMediaPreviewResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseMedia(MiniProgramMediaReleaseRequest request) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited