Optional session surface for providers that support native fullscreen video.
Keeping this separate preserves source compatibility for Phase 1 provider implementations while allowing the runtime to expose fullscreen actions.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enterFullscreen(
) → Future< void> -
exitFullscreen(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited