MiniProgramMediaPlaybackManager class

App-scoped session owner shared by actions and inline video nodes.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
load(MiniProgramMediaPlaybackRequest request) Future<MiniProgramMediaPlaybackSession>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseAllFor(String appId) Future<void>
Pauses all active foreground sessions owned by appId.
release(String appId, String playerId) Future<bool>
releaseAllFor(String appId) Future<void>
sessionFor(String appId, String playerId) MiniProgramMediaPlaybackSession?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited