MiniProgramMediaPlaybackPolicy class

Host authority for streamed foreground audio and inline video playback.

Annotations

Constructors

MiniProgramMediaPlaybackPolicy({bool audioEnabled = false, bool videoEnabled = false, bool temporaryCacheEnabled = false, bool? audioTemporaryCacheEnabled, bool? videoTemporaryCacheEnabled})
const

Properties

audioEnabled bool
final
audioTemporaryCacheEnabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporaryCacheEnabled bool
final
videoEnabled bool
final
videoTemporaryCacheEnabled bool
final

Methods

allows(MiniProgramMediaPlaybackKind kind) bool
allowsTemporaryCache(MiniProgramMediaPlaybackKind kind) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited