MiniProgramMediaPlaybackRequest class

Creation request passed to a trusted playback provider.

Annotations

Constructors

MiniProgramMediaPlaybackRequest({required String miniProgramId, required String playerId, required MiniProgramMediaPlaybackKind kind, required String sourceKey, required MiniProgramResolvedPlaybackSource source, required MiniProgramMediaCacheMode cacheMode, required bool autoplay, required bool loop, required double volume, required double speed, required bool muted, int? maxCacheBytes, Duration? cacheTtl})
const

Properties

autoplay bool
final
cacheMode MiniProgramMediaCacheMode
final
cacheTtl Duration?
final
hashCode int
The hash code for this object.
no setterinherited
kind → MiniProgramMediaPlaybackKind
final
loop bool
final
maxCacheBytes int?
final
miniProgramId String
final
muted bool
final
playerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source MiniProgramResolvedPlaybackSource
final
sourceKey String
final
speed double
final
volume double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited