MiniProgramDiscoveryState class

Resolved discovery state for one mini-program in a host list.

Annotations

Constructors

MiniProgramDiscoveryState({required String miniProgramId, required MiniProgramDiscoveryStatus status, MiniProgramManifest? manifest, String? message, String? errorCode, DateTime? manifestCachedAt, DateTime? entryScreenCachedAt, Map<String, dynamic> details = const <String, dynamic>{}})
const

Properties

badgeLabel String
no setter
canOpen bool
no setter
details Map<String, dynamic>
final
displayMessage String
no setter
entryScreenCachedAt DateTime?
final
errorCode String?
final
hashCode int
The hash code for this object.
no setterinherited
manifest → MiniProgramManifest?
final
manifestCachedAt DateTime?
final
message String?
final
miniProgramId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status MiniProgramDiscoveryStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited