MiniProgramLoadException class

Internal exception used to move structured failure details through futures.

Implemented types

Constructors

MiniProgramLoadException(MiniProgramFailure failure)
const

Properties

failure MiniProgramFailure
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited