MiniProgramLaunchRequest class

Annotations

Constructors

MiniProgramLaunchRequest({required String appId, required MiniProgramRuntime runtime, required Widget page, required MiniProgramLaunchOptions options, String? title, Map<String, dynamic>? initialData, String? version, Uri? source})
const

Properties

appId String
final
hashCode int
The hash code for this object.
no setterinherited
initialData Map<String, dynamic>?
final
miniProgramId String
no setter
options MiniProgramLaunchOptions
final
page Widget
final
runtime MiniProgramRuntime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Uri?
final
title String?
final
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited