openMiniProgram<T> function

  1. @Deprecated('Use MiniProgramScope.of(context).openMiniProgram(appId: ...) instead. ' 'The free launcher helper will be removed in the next major version.')
Future<T?> openMiniProgram<T>(
  1. BuildContext context, {
  2. required String miniProgramId,
  3. String? title,
  4. MiniProgramRuntime? runtime,
  5. bool useRootNavigator = false,
  6. LegacyMiniProgramRouteBuilder<T>? routeBuilder,
})

Implementation

@Deprecated(
  'Use MiniProgramScope.of(context).openMiniProgram(appId: ...) instead. '
  'The free launcher helper will be removed in the next major version.',
)
Future<T?> openMiniProgram<T>(
  BuildContext context, {
  required String miniProgramId,
  String? title,
  MiniProgramRuntime? runtime,
  bool useRootNavigator = false,
  LegacyMiniProgramRouteBuilder<T>? routeBuilder,
}) {
  return _pushMiniProgramPage<T>(
    context,
    page: MiniProgramPage(
      miniProgramId: miniProgramId,
      title: title,
      runtime: runtime,
    ),
    useRootNavigator: useRootNavigator,
    routeBuilder: routeBuilder,
  );
}