AssetResolutionResult class

Constructors

AssetResolutionResult({required Map<String, dynamic> screenJson, int cachedAssetCount = 0, int downloadedAssetCount = 0, int failedAssetCount = 0})
const

Properties

cachedAssetCount int
final
downloadedAssetCount int
final
failedAssetCount int
final
hashCode int
The hash code for this object.
no setterinherited
resolvedAssetCount int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenJson Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited