Shared local artifact endpoint defaults for generated host apps.
The host app can always override the resolved base URL with an explicit
legacy-named MINI_PROGRAM_BACKEND_BASE_URL value. When only a host and/or
port needs to change for local development, prefer
MINI_PROGRAM_BACKEND_HOST and MINI_PROGRAM_BACKEND_PORT.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultHost(
{TargetPlatform? platform, bool isWeb = kIsWeb}) → String -
resolveBaseUri(
{String configuredBaseUrl = '', String configuredHost = '', int configuredPort = defaultPort, String path = defaultPath, TargetPlatform? platform, bool isWeb = kIsWeb}) → Uri
Constants
- defaultPath → const String
- defaultPort → const int