MiniProgramBackendEndpoint class

Annotations

Constructors

MiniProgramBackendEndpoint({required Uri baseUri, Map<String, String> headers = const <String, String>{}, Duration requestTimeout = const Duration(seconds: 8), bool enableLocalLoopbackFallback = true})
const

Properties

baseUri Uri
final
enableLocalLoopbackFallback bool
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
requestTimeout Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited