MiniProgramBackendRequest class

Annotations

Constructors

MiniProgramBackendRequest({required String miniProgramId, required String endpoint, String? requestId, String method = 'GET', Map<String, dynamic> body = const <String, dynamic>{}, Map<String, String> headers = const <String, String>{}, MiniProgramBackendCachePolicy cachePolicy = const MiniProgramBackendCachePolicy.noCache(), bool forceRefresh = false})
const

Properties

body Map<String, dynamic>
final
cachePolicy MiniProgramBackendCachePolicy
final
endpoint String
final
forceRefresh bool
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
method String
final
miniProgramId String
final
requestId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Map<String, String>? headers, MiniProgramBackendCachePolicy? cachePolicy, bool? forceRefresh}) MiniProgramBackendRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited