MiniProgramBackendQuery class
- Annotations
Constructors
Properties
-
body
→ Map<
String, dynamic> -
final
- cacheTtl → Duration?
-
final
- endpoint → String
-
final
- forceRefresh → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toRequest(
{required String miniProgramId}) → MiniProgramBackendRequest -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited