MiniProgramPagedBackendSnapshot class

Annotations

Constructors

MiniProgramPagedBackendSnapshot({required String requestId, required MiniProgramBackendSnapshotStatus status, String? endpoint, String method = 'GET', int? statusCode, String? message, String? errorCode, List<Object?> items = const <Object?>[], Object? nextCursor, bool hasMore = false, int pageCount = 0, bool loadingMore = false, bool fromCache = false, DateTime? updatedAt})
const
MiniProgramPagedBackendSnapshot.fromResult(MiniProgramBackendResult result, {required String requestId, required MiniProgramPagedBackendQuery query, required bool append, MiniProgramPagedBackendSnapshot? previous})
factory
MiniProgramPagedBackendSnapshot.idle(String requestId)
factory
MiniProgramPagedBackendSnapshot.loading({required String requestId, required String endpoint, MiniProgramPagedBackendSnapshot? previous, bool loadingMore = false})
factory

Properties

endpoint String?
final
errorCode String?
final
fromCache bool
final
hashCode int
The hash code for this object.
no setterinherited
hasItems bool
no setter
hasMore bool
final
isFailure bool
no setter
isIdle bool
no setter
isLoading bool
no setter
isSuccess bool
no setter
items List<Object?>
final
loadingMore bool
final
message String?
final
method String
final
nextCursor Object?
final
pageCount int
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status MiniProgramBackendSnapshotStatus
final
statusCode int?
final
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBindingData() Map<String, dynamic>
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited