MiniProgramDeliveryContext class

Shared manifest-delivery query context for backend-hosted mini-programs.

Annotations

Constructors

MiniProgramDeliveryContext({required String hostApp, required String sdkVersion, required String hostVersion, required Set<CapabilityId> capabilities, String? platform, String? locale, String? tenantId, String? pinnedVersion})
const

Properties

capabilities Set<CapabilityId>
final
hashCode int
The hash code for this object.
no setterinherited
hostApp String
final
hostVersion String
final
locale String?
final
pinnedVersion String?
final
platform String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkVersion String
final
tenantId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParameters() Map<String, String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited