Optional contract for sources that own disposable resources.
- Implemented types
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
loadManifest(
String miniProgramId) → Future< MiniProgramManifest> -
inherited
-
loadScreen(
{required String miniProgramId, required String version, required String screenId}) → Future< Map< String, dynamic> > -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited