MiniProgramJsonAssetSource class abstract interface

Optional source capability for immutable JSON files under artifact assets.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadJsonAsset({required String miniProgramId, required String version, required String assetPath}) Future<List<int>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited