MiniProgramResolvedMediaAsset class

Resolved immutable artifact media visible only to a trusted host provider.

Constructors

MiniProgramResolvedMediaAsset({required List<Uri> candidateUris, Map<String, String> headers = const <String, String>{}, Duration timeout = const Duration(seconds: 10)})
const

Properties

candidateUris List<Uri>
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited