MiniProgramSourceException class

Structured source-layer failure used by backend and asset loaders.

Implemented types

Constructors

MiniProgramSourceException({required String message, String? errorCode, int? statusCode, Map<String, dynamic> details = const <String, dynamic>{}})
const

Properties

details Map<String, dynamic>
final
errorCode String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited