Minimal logger contract used by the SDK for diagnostics and failures.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
error(
String message, {Object? error, StackTrace? stackTrace, Map< String, Object?> context = const {}}) → void -
info(
String message, {Map< String, Object?> context = const {}}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
warn(
String message, {Map< String, Object?> context = const {}}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited