MiniProgramQrManager class

Owns one active scanner request and enforces app-scoped cancellation.

Properties

hashCode int
The hash code for this object.
no setterinherited
provider MiniProgramQrScannerProvider
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseFor(String miniProgramId) Future<void>
scan({required String miniProgramId, required bool allowTorch, required Duration timeout}) Future<MiniProgramQrScanResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited