MiniProgramQrScanRequest class
Trusted request passed to a host QR scanner implementation.
- Annotations
Constructors
- MiniProgramQrScanRequest({required String scanId, required String miniProgramId, required bool allowTorch, required Duration timeout})
-
const
Properties
- allowTorch → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- miniProgramId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanId → String
-
final
- timeout → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited