MiniProgramBackendBindingResolver class

Constructors

MiniProgramBackendBindingResolver()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readPath(Object? source, String path) Object?
resolveTemplate(dynamic template, {required MiniProgramBackendStore store, Map<String, dynamic>? item, Map<String, dynamic> bindings = const <String, dynamic>{}}) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited