MiniProgramRenderException class

Controlled rendering failure that can be converted to SDK error UI.

Implemented types

Constructors

MiniProgramRenderException({required String message, String errorCode = MiniProgramErrorCodes.manifestParseFailure, Map<String, dynamic> details = const <String, dynamic>{}})
Creates a controlled render exception.
const

Properties

details Map<String, dynamic>
Diagnostic details safe to expose through SDK failure state.
final
errorCode String
Stable SDK error code.
final
hashCode int
The hash code for this object.
no setterinherited
message String
User-facing failure message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFailure({required MiniProgramManifest manifest, required String screenId, Object? cause, StackTrace? stackTrace}) MiniProgramFailure
Converts this render exception to a mini-program failure.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited