MiniProgramScreenRendererRegistry class

Immutable registry of available screen renderers.

Constructors

MiniProgramScreenRendererRegistry(Iterable<MiniProgramScreenRenderer> renderers)
Creates a renderer registry from explicit renderers.
MiniProgramScreenRendererRegistry.withDefaults([Iterable<MiniProgramScreenRenderer> renderers = const <MiniProgramScreenRenderer>[]])
Creates a registry with built-in renderers plus optional additions.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenFormats Set<String>
Registered screen formats.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(MiniProgramManifest manifest) MiniProgramScreenRenderer
Resolves a renderer for manifest.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultRenderers → const List<MiniProgramScreenRenderer>
Built-in screen renderers.