MpScreenRenderer class
Renderer for versioned Mp JSON screen documents.
- Inheritance
-
- Object
- MiniProgramScreenRenderer
- MpScreenRenderer
Constructors
- MpScreenRenderer()
-
Creates the Mp renderer.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenFormat → String
-
Manifest
screenFormatvalue this renderer supports.no setteroverride -
supportedSchemaVersions
→ Set<
int> -
Supported schema versions. Empty means schema-less legacy format.
no setteroverride
Methods
-
ensureInitialized(
{required SdkLogger logger}) → Future< void> -
Performs async one-time setup before rendering.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
MiniProgramRenderRequest request) → Widget -
Renders a validated screen into Flutter widgets.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited