MpScreenValidator class

Validates Mp screen documents against the SDK-supported schema.

Constructors

MpScreenValidator()
Creates an Mp validator.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(Map<String, dynamic> json, {required String expectedScreenId}) → void
Validates an Mp screen document without rendering it.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

maxActionDefinitions → const int
Maximum reusable actions defined by one action scope.
maxCountdownDurationMs → const int
Maximum countdown duration accepted by the runtime.
maxDepth → const int
Maximum node nesting depth.
maxDirectChildren → const int
Maximum direct children for one node.
maxLiteralTextLength → const int
Maximum text/string literal length.
maxNodes → const int
Maximum number of nodes in one screen.
maxPayloadBytes → const int
Maximum encoded screen payload accepted by the SDK.
maxUrlLength → const int
Maximum accepted URL string length.