MiniProgramShareManager class

Validates share content and prevents concurrent chooser requests.

Properties

hashCode int
The hash code for this object.
no setterinherited
provider MiniProgramShareProvider
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({required String miniProgramId, String? title, String? text, Uri? url, List<String> mediaRefs = const <String>[]}) Future<MiniProgramShareResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited