MiniProgramSharePolicy class
Host authority for opening the platform share chooser.
- Annotations
Constructors
-
const
Properties
- allowMedia → bool
-
final
- allowText → bool
-
final
- allowUrls → bool
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxMediaItems → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override