MiniProgramShareRequest class

Trusted, validated request passed to the host share implementation.

Annotations

Constructors

MiniProgramShareRequest({required String miniProgramId, String? title, String? text, Uri? url, List<String> mediaRefs = const <String>[]})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mediaRefs List<String>
final
miniProgramId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final
title String?
final
url Uri?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited