MiniProgramLiveStatePolicy class

Host-owned memory limits for one active mini-program state namespace.

Annotations

Constructors

MiniProgramLiveStatePolicy({int maxBytes = 2 * 1024 * 1024, int maxEntries = 1000, int maxValueBytes = 256 * 1024, int maxDepth = 32})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxBytes int
final
maxDepth int
final
maxEntries int
final
maxValueBytes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited