MiniProgramLiveStatePolicyProvider class abstract interface

Supplies per-mini-program live-state policy to the runtime host.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

liveStatePolicyFor(String miniProgramId) MiniProgramLiveStatePolicy
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited