MiniProgramStateLimitException class

Raised when a live-state write would exceed host-owned limits.

Implemented types

Constructors

MiniProgramStateLimitException({required String metric, required int limit, required int actual})
const

Properties

actual int
final
details Map<String, dynamic>
no setter
hashCode int
The hash code for this object.
no setterinherited
limit int
final
metric String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited