SecureMiniProgramAuthStore class
- Implemented types
Constructors
- SecureMiniProgramAuthStore({FlutterSecureStorage? storage})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String miniProgramId) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String miniProgramId) → Future< MiniProgramAuthSession?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
String miniProgramId, MiniProgramAuthSession session) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited