SharedPreferencesMiniProgramCacheStore class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appIds(
) → Future< List< String> > -
override
-
clearApp(
String appId) → Future< void> -
override
-
clearBucket(
String appId, MiniProgramCacheBucket bucket) → Future< void> -
override
-
entries(
String appId) → Future< List< MiniProgramCacheEntry> > -
override
-
get(
String namespacedKey) → Future< MiniProgramCacheEntry?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String namespacedKey) → Future< void> -
override
-
set(
MiniProgramCacheEntry entry) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
totalBytes(
String appId) → Future< int> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited