MiniProgramCacheBucketUsage class
- Annotations
Constructors
- MiniProgramCacheBucketUsage({required MiniProgramCacheBucket bucket, required bool enabledForMiniProgram, required int usedBytes, required int miniProgramUsedBytes, required int? maxBytes, required int? remainingBytes, required Duration ttl, required int entryCount, required int miniProgramEntryCount})
-
const
Properties
- bucket → MiniProgramCacheBucket
-
final
- enabledForMiniProgram → bool
-
final
- entryCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBytes → int?
-
final
- miniProgramEntryCount → int
-
final
- miniProgramUsedBytes → int
-
final
- remainingBytes → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ttl → Duration
-
final
- usedBytes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited