MiniProgramCacheEntry class
- Annotations
Constructors
- MiniProgramCacheEntry({required String appId, required MiniProgramCacheBucket bucket, required String key, required Object? value, required DateTime createdAt, required DateTime updatedAt, required DateTime lastAccessedAt, required DateTime expiresAt, required int sizeBytes, required MiniProgramCachePriority priority})
-
const
Properties
- appId → String
-
final
- bucket → MiniProgramCacheBucket
-
final
- createdAt → DateTime
-
final
- expiresAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- lastAccessedAt → DateTime
-
final
- namespacedKey → String
-
no setter
- priority → MiniProgramCachePriority
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeBytes → int
-
final
- updatedAt → DateTime
-
final
- value → Object?
-
final
Methods
-
copyWith(
{Object? value = _unset, DateTime? updatedAt, DateTime? lastAccessedAt, DateTime? expiresAt, int? sizeBytes, MiniProgramCachePriority? priority}) → MiniProgramCacheEntry -
isExpired(
DateTime now) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited