MiniProgramCameraManager class
Owns camera request identity and temporary media lifetime per app.
Constructors
- MiniProgramCameraManager(MiniProgramCameraProvider provider, {MiniProgramMediaManager? mediaManager})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mediaManager → MiniProgramMediaManager?
-
final
- provider → MiniProgramCameraProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelFor(
String miniProgramId) → Future< bool> -
capturePhoto(
{required String miniProgramId, required int quality, int? maxWidth, int? maxHeight}) → Future< MiniProgramCameraPhotoResult> -
dispose(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
releaseAllFor(
String miniProgramId) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited