MiniProgramDataResourceLoadResult class
A validated artifact-local JSON resource load result.
Constructors
- MiniProgramDataResourceLoadResult({required String id, required String asset, required bool fromCache, required int bytes})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited