MiniProgramFileDownloadRequest class
Download request passed only to a trusted host file provider.
- Annotations
Constructors
-
MiniProgramFileDownloadRequest({required String transferId, required String miniProgramId, required MiniProgramResolvedBackendTransfer backend, required Map<
String, dynamic> request, required MiniProgramFileDownloadDestination destination, required int? maxFileBytes, required int minimumFreeBytes, required int maxConcurrentTransfers, String? suggestedName, String? expectedMimeType}) -
const
Properties
- backend → MiniProgramResolvedBackendTransfer
-
final
- destination → MiniProgramFileDownloadDestination
-
final
- expectedMimeType → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrentTransfers → int
-
final
- maxFileBytes → int?
-
final
- minimumFreeBytes → int
-
final
- miniProgramId → String
-
final
-
request
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestedName → String?
-
final
- transferId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited