MiniProgramFileTransferResult class
Normalized transfer result returned by a trusted host provider.
- Annotations
Constructors
Properties
- bytesTransferred → int
-
final
-
data
→ Map<
String, dynamic> -
final
- destination → String?
-
final
- direction → MiniProgramFileTransferDirection
-
final
- fileName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
- transferId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited