LoadedMiniProgram class
Fully resolved mini-program state ready for rendering.
Constructors
-
LoadedMiniProgram({required MiniProgramManifest manifest, required Map<
String, dynamic> entryScreenJson, MiniProgramPublisherBackendContract? publisherBackendContract, bool usedStaleManifestCache = false, bool usedStaleEntryScreenCache = false, int cachedAssetCount = 0, int downloadedAssetCount = 0, int failedAssetCount = 0}) -
const
Properties
- cachedAssetCount → int
-
final
- downloadedAssetCount → int
-
final
-
entryScreenJson
→ Map<
String, dynamic> -
final
- failedAssetCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manifest → MiniProgramManifest
-
final
- publisherBackendContract → MiniProgramPublisherBackendContract?
-
final
- resolvedAssetCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usedStaleCache → bool
-
no setter
- usedStaleEntryScreenCache → bool
-
final
- usedStaleManifestCache → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited