ManifestLoader class
Loads, validates, and resolves the entry screen for a mini-program.
Constructors
- ManifestLoader({VersionValidator versionValidator = const VersionValidator()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- versionValidator → VersionValidator
-
final
Methods
-
load(
{required String miniProgramId, required String sdkVersion, required MiniProgramSource source, required ManifestCache manifestCache, required ScreenCache screenCache, required CapabilityRegistry capabilityRegistry, required FeatureFlagEvaluator featureFlagEvaluator, required SdkLogger logger}) → Future< LoadedMiniProgram> -
loadScreen(
{required String miniProgramId, required MiniProgramManifest manifest, required String screenId, required MiniProgramSource source, required ScreenCache screenCache, required SdkLogger logger}) → Future< LoadedMiniProgramScreen> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited