One host-owned playback session. URLs and request headers stay private.
- Implemented types
Properties
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
buildVideoView(
{required BoxFit fit, required bool controls, required String semanticLabel}) → Widget -
dispose(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → Future< void> -
play(
) → Future< void> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
seek(
Duration position) → Future< void> -
setMuted(
bool muted) → Future< void> -
setSpeed(
double speed) → Future< void> -
setVolume(
double volume) → Future< void> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited