MiniProgramController class
Constructors
- MiniProgramController({required MiniProgramConfig config, })
- MiniProgramController.runtime(MiniProgramRuntime runtime, {bool disposeRuntime = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- runtime → MiniProgramRuntime
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openMiniProgram<
T> (BuildContext context, {required String appId, String? title, Map< String, dynamic> ? initialData, String? version, Uri? source, MiniProgramLaunchOptions options = const MiniProgramLaunchOptions()}) → Future<T?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited