MiniProgramDiscoveryResolver class

Resolves list-level availability without fully opening the mini-program UI.

Constructors

MiniProgramDiscoveryResolver({DateTime now()?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({required String miniProgramId, required MiniProgramSource source, required ManifestCache manifestCache, required ScreenCache screenCache, required MiniProgramDiscoverySourceKind sourceKind}) Future<MiniProgramDiscoveryState>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited