MiniProgramDiscoveryStatus enum
User-facing availability state for a mini-program card in host discovery UI.
Values
- live → const MiniProgramDiscoveryStatus
-
The backend is reachable and the current release can be opened normally.
- cached → const MiniProgramDiscoveryStatus
-
The release is available from a bundled or local copy.
- staleButAllowed → const MiniProgramDiscoveryStatus
-
The backend is unavailable, but a valid cached copy may still be opened.
-
No current or valid offline copy is available to open.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MiniProgramDiscoveryStatus> - A constant List of the values in this enum, in order of their declaration.