MiniProgramFailure class
Failure details surfaced by the SDK when a mini-program cannot continue.
- Annotations
Constructors
-
MiniProgramFailure({required String message, String? errorCode, Map<
String, dynamic> details = const <String, dynamic>{}, MiniProgramFallback? fallback, Object? cause, StackTrace? stackTrace}) -
const
Properties
- cause → Object?
-
final
-
details
→ Map<
String, dynamic> -
final
- displayMessage → String
-
no setter
- errorCode → String?
-
final
- fallback → MiniProgramFallback?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited