MiniProgramLaunchOptions class
- Annotations
Constructors
- MiniProgramLaunchOptions({bool fullscreenDialog = false, bool showAppBar = true, Color? backgroundColor, RouteSettings? routeSettings, MiniProgramRouteBuilder? routeBuilder})
-
const
Properties
- backgroundColor → Color?
-
final
- fullscreenDialog → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- routeBuilder → MiniProgramRouteBuilder?
-
final
- routeSettings → RouteSettings?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAppBar → bool
-
final
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited