AssetResolver class
Resolves standard Mp image nodes to local file-backed assets when the manifest allows entry-screen caching.
Constructors
- AssetResolver({Client? client})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveEntryScreenAssets(
{required MiniProgramManifest manifest, required Map< String, dynamic> screenJson, required AssetCache assetCache, required SdkLogger logger}) → Future<AssetResolutionResult> -
resolveScreenAssets(
{required MiniProgramManifest manifest, required String screenId, required Map< String, dynamic> screenJson, required AssetCache assetCache, required SdkLogger logger}) → Future<AssetResolutionResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited