MiniProgramBackendResult class
- Annotations
Constructors
-
MiniProgramBackendResult({required MiniProgramBackendResultStatus status, String? requestId, String? endpoint, String? method, int? statusCode, String? message, String? errorCode, Map<
String, dynamic> data = const <String, dynamic>{}, bool fromCache = false}) -
const
-
MiniProgramBackendResult.failed({String? requestId, String? endpoint, String? method, int? statusCode, String? message, String? errorCode, Map<
String, dynamic> data = const <String, dynamic>{}}) -
factory
-
MiniProgramBackendResult.success({String? requestId, String? endpoint, String? method, int? statusCode, String? message, Map<
String, dynamic> data = const <String, dynamic>{}, bool fromCache = false}) -
factory
Properties
-
data
→ Map<
String, dynamic> -
final
- endpoint → String?
-
final
- errorCode → String?
-
final
- fromCache → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFailure → bool
-
no setter
- isSuccess → bool
-
no setter
- message → String?
-
final
- method → String?
-
final
- requestId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → MiniProgramBackendResultStatus
-
final
- statusCode → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited