MiniProgramBackendSnapshot class
- Annotations
Constructors
-
MiniProgramBackendSnapshot({required String requestId, required MiniProgramBackendSnapshotStatus status, String? endpoint, String? method, int? statusCode, String? message, String? errorCode, Map<
String, dynamic> data = const <String, dynamic>{}, bool fromCache = false, DateTime? updatedAt}) -
const
- MiniProgramBackendSnapshot.fromResult(MiniProgramBackendResult result, {required String requestId, MiniProgramBackendSnapshot? previous})
-
factory
- MiniProgramBackendSnapshot.idle(String requestId)
-
factory
- MiniProgramBackendSnapshot.loading({required String requestId, required String endpoint, required String method, MiniProgramBackendSnapshot? previous})
-
factory
Properties
-
data
→ Map<
String, dynamic> -
final
- endpoint → String?
-
final
- errorCode → String?
-
final
- fromCache → bool
-
final
- hasData → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFailure → bool
-
no setter
- isIdle → bool
-
no setter
- isLoading → bool
-
no setter
- isSuccess → bool
-
no setter
- message → String?
-
final
- method → String?
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → MiniProgramBackendSnapshotStatus
-
final
- statusCode → int?
-
final
- updatedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBindingData(
) → Map< String, dynamic> -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited