MiniProgramPagedBackendQuery class

Annotations

Constructors

MiniProgramPagedBackendQuery({required String requestId, required String endpoint, int limit = 20, String? initialCursor, String cursorParam = 'cursor', String limitParam = 'limit', String itemsPath = 'items', String nextCursorPath = 'nextCursor', String hasMorePath = 'hasMore', Duration? cacheTtl, bool forceRefresh = false})
const

Properties

cacheTtl Duration?
final
cursorParam String
final
endpoint String
final
forceRefresh bool
final
hashCode int
The hash code for this object.
no setterinherited
hasMorePath String
final
initialCursor String?
final
itemsPath String
final
limit int
final
limitParam String
final
nextCursorPath String
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRequest({required String miniProgramId, Object? cursor}) MiniProgramBackendRequest
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited