MiniProgramRenderRequest class

Input passed to a screen renderer for one loaded mini-program screen.

Annotations

Constructors

MiniProgramRenderRequest({required BuildContext context, required MiniProgramManifest manifest, required String screenId, required Map<String, dynamic> screenJson, required SdkLogger logger})
Creates a render request for a screen document.
const

Properties

context BuildContext
Build context inside MiniProgramSdkScope.
final
hashCode int
The hash code for this object.
no setterinherited
logger SdkLogger
SDK logger for controlled diagnostics.
final
manifest → MiniProgramManifest
Manifest that selected this renderer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenId String
Screen ID being rendered.
final
screenJson Map<String, dynamic>
Raw loaded screen JSON.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited