MpActionRunner class
Runs validated Mp JSON actions against the active SDK scope.
Constructors
- MpActionRunner()
-
Creates an Mp action runner.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
BuildContext context, Map< String, dynamic> actionJson, {Map<String, dynamic> ? item, Map<String, dynamic> ? form, bool userGesture = false}) → Future<Object?> - Parses and runs a single action JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited