MiniProgramStateLimitException class
Raised when a live-state write would exceed host-owned limits.
- Implemented types
Constructors
- MiniProgramStateLimitException({required String metric, required int limit, required int actual})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited